package com.qmth.ops.biz.service;

import com.qmth.boot.mybatis.service.SqlProvider;
import com.qmth.boot.tools.models.ByteArray;
import com.qmth.ops.api.security.Permission;
import com.qmth.ops.biz.domain.Role;
import com.qmth.ops.biz.domain.User;
import com.qmth.ops.biz.domain.UserPermission;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.Arrays;
import java.util.stream.Collectors;

@Service
public class InitService implements SqlProvider, CommandLineRunner {

    private static final Logger log = LoggerFactory.getLogger(InitService.class);

    @Resource
    private UserService userService;

    @Resource
    private UserPermissionService userPermissionService;

    @Override
    public String get() {
        try {
            return ByteArray.fromInputStream(this.getClass().getClassLoader().getResourceAsStream("script/init.sql"))
                    .toString();
        } catch (IOException e) {
            throw new RuntimeException("数据库初始化异常", e);
        }
    }

    @Override
    public void run(String... args) {
        if (userService.count() == 0) {
            User user = new User();
            user.setLoginName("admin");
            user.setName("系统管理员");
            user.setPassword("123456");
            user.setRole(new Role[] { Role.ADMIN });
            user.setEnable(true);
            userService.insert(user);
            log.info("系统管理员初始化完成");
        }

        User user = userService.findByLoginName("admin");
        if (user != null && user.hasRole(Role.ADMIN)) {
            userPermissionService.save(user, Arrays.stream(Permission.values()).map(p -> {
                UserPermission up = new UserPermission();
                up.setUserId(user.getId());
                up.setPermission(p);
                up.setScope(UserPermission.UNLIMIT_SCOPE);
                return up;
            }).collect(Collectors.toList()));
            log.info("系统管理员权限更新完成");
        }
    }

}
